/*****************************************************************************
*                             MODULE DESCRIPTION
******************************************************************************
*
*      NAME:     KoppeloRights.java
*      LANGUAGE: JavaBean
*      DATE:     23.5.2002
*      AUTHOR:   Minna Hillebrand, Jyvskyl University (JYU)
*      PURPOSE:  Check if given person/role/userGroup has right to
*                perform specified action in KOPPELO system.
*
******************************************************************************
*                  COPYRIGHT (C) KOTKA-PROJEKTIRYHM
*             Limited rights granted. Please refer to license
*****************************************************************************/

/*****************************************************************************
*                                  UPDATES
******************************************************************************
*
*
*
*****************************************************************************/

package kotkabeans;

import java.sql.*;

/**
 * implements KoppeloRights object.
 */

public class KoppeloRights {

        private DB db;


// Constructors

	/**
	 * Dummy empty constructor. 
	 */

	public KoppeloRights() {}

	/**
	 * Constructs KoppeloRights object 
	 *
	 * @param db Database object to be used
	 */
	public KoppeloRights(DB db) { setDB(db); }


       // Access methods

       public void setDB(DB db) {
		this.db = db;
	}


        /**
	 * Exceute query to find out if given person has specified right
	 *
	 * @param rightid  The right we are interested in
	 * @param personid The person we are interested in
	 * @param typeid   The assignment type we are interested in
	 * @param lineid   The studyline we are interested in, values <= 0 meaning null
	 */
 
          public boolean hasPersonRight(int rightid, int personid, int typeid, int lineid) {
		 
	        boolean hasRight = false;
		boolean wasConnected = false;
                try {
		  if(!db.isConnected()) db.connect();
	 	  else wasConnected = true;
		} catch (Exception muuta) {}
		
		String query = 
		     " select distinct true as juttunen"
	           + " from asspersonrelright"  
		   + " where asspersonrelright.deleted = false"
		   + " and   asspersonrelright.personid = " + Integer.toString(personid)
		   + " and   asspersonrelright.rightid = " + Integer.toString(rightid)
		   + " and   asspersonrelright.asstypeid = "  + Integer.toString(typeid);
                if (lineid > 0)
		    query += " and   asspersonrelright.lineid = " + Integer.toString(lineid);
	        query+= ";"; 

		try {
		    ResultSet rs = db.executeQuery(query);
		      if ( rs.next() )
			  hasRight = rs.getBoolean("juttunen");
                } catch (Exception e) {
                        System.out.println(e.getMessage());
                }	
		
	        try {
                  if(!wasConnected) db.disconnect();
                 } catch (Exception jotain) {}                         
		return hasRight;		 
	}
    

        /**
	 * Exceute query to find out if given person has specified right in specified assignment 
	 *
	 * @param rightid  The right we are interested in
	 * @param personid The person we are interested in
	 * @param assid    The assignment we are interested in
	 */
             public boolean hasPersonRight(int rightid, int personid, int assid) {

      	        boolean hasRight = false;
		boolean wasConnected = false;
                try {
		  if(!db.isConnected()) db.connect();
	 	  else wasConnected = true;
		} catch (Exception muuta) {}
		
		String query = 
		     " select distinct true as juttunen"
                   + " from   asspersonrelright"  
		   + " where  asspersonrelright.deleted = false"
		   + " and    asspersonrelright.personid = "+ Integer.toString(personid)
		   + " and    asspersonrelright.rightid = " + Integer.toString(rightid)
		   + " and    asspersonrelright.asstypeid = ( "
		   + "                         select assignmenttypeid "
                   + "                         from assignment "
                   + "                         where assignmentid = " + Integer.toString(assid) + ")"

		    // Huomaa ett linjan ksittely puuttuu kokonaan, voi olla null

		   + " union " 
		   + " select distinct true as juttunen"
                   + " from   assrolerelright"  
		   + " where  assrolerelright.deleted = false"
		   + " and    assrolerelright.rightid = " + Integer.toString(rightid)
		   + " and    assrolerelright.roleid = assignmentrelatedperson.roleid"
		   + " and    assignmentrelatedperson.deleted = false" 
		   + " and    assignmentrelatedperson.personid = " + Integer.toString(personid)
		   + " and    assignmentrelatedperson.assignmentid = " +  Integer.toString(assid)

		   + " union " 
		   + " select distinct true as juttunen"
                   + " from   assusergrouprelright"  
		   + " where  assusergrouprelright.deleted = false"
		   + " and    assusergrouprelright.rightid = "+ Integer.toString(rightid)
		   + " and    assusergrouprelright.groupid = accessrightlevel.accessrightlevelid"
                   + " and    accessrightlevel.accessrightlevelid = accessright.accessrightlevelid"
                   + " and    accessright.personid = " + Integer.toString(personid)
		   + " and    accessright.deleted = false;";

		try {
		    ResultSet rs = db.executeQuery(query);
		      if ( rs.next() )
			  hasRight = rs.getBoolean("juttunen");		    
                } catch (Exception e) { System.out.println(e.getMessage()); }	
		
	        try {
                    if(!wasConnected) db.disconnect();
                 } catch (Exception jotain) {}                         

		return hasRight;
       	}



        /**
	 * Exceute query to find out if given person has specified right
	 *
	 * @param rightid  The right we are interested in
	 * @param personid The person we are interested in
	 * @param origid   The assignment original we are interested in
	 */
             public boolean hasPersonRightOriginal(int rightid, int personid, int origid) {
		 
	        boolean hasRight = false;
      		boolean wasConnected = false;
                try {
		  if(!db.isConnected()) db.connect();
	 	  else wasConnected = true;
		} catch (Exception muuta) {}
		
		String query = 
		      " select distinct true as juttunen "  
		    + " from  asspersonrelright "
		    + " where asspersonrelright.deleted = false"
		    + " and   asspersonrelright.personid = " + Integer.toString(personid)
		    + " and   asspersonrelright.rightid = " + Integer.toString(rightid)
                    + " and   asspersonrelright.lineid in ("
	       	    + "                             select lineid" 
		    + "				    from   assoriginalposline "
		    + "				    where  assoriginalposline.originalid = " + Integer.toString(origid)
		    + "				    and    assoriginalposline.deleted = false "
		    + "				    ) "
		    + " and   asspersonrelright.asstypeid in ("
		    + "					     select typeid" 
		    + "					     from   assoriginalpostype" 
		    + "					     where  assoriginalpostype.originalid = " + Integer.toString(origid)
		    + "					     and    assoriginalpostype.deleted = false"
		    + "					     ) "
                    + " and   asspersonrelright.lineid in ("
	       	    + "                             select lineid" 
		    + "				    from   assoriginalposline "
		    + "				    where  assoriginalposline.originalid = " + Integer.toString(origid)
		    + "				    and    assoriginalposline.deleted = false "
		    + "				    ) "
		    + " union "
		    + " select distinct true as juttunen "  
		    + " from  asspersonrelright "
		    + " where asspersonrelright.deleted = false"
		    + " and   asspersonrelright.personid = " + Integer.toString(personid)
		    + " and   asspersonrelright.rightid = " + Integer.toString(rightid)
		    + " and " + Integer.toString(origid) + " not in ("
		    + "                       select originalid "
		    + "			      from assoriginalposline "
		    + "			      where assoriginalposline.deleted = false)"
		    + "	;";

		/*
		String query = 
		      " select distinct true as juttunen "  
		    + " from  asspersonrelright "
		    + " where asspersonrelright.deleted = false"
		    + " and   asspersonrelright.personid = " + Integer.toString(personid)
		    + " and   asspersonrelright.rightid = " + Integer.toString(rightid)
                    + " and   asspersonrelright.lineid in ("
	       	    + "                             select lineid" 
		    + "				    from   assoriginalposline "
		    + "				    where  assoriginalposline.originalid = " + Integer.toString(origid)
		    + "				    and    assoriginalposline.deleted = false "
		    + "				    ) "
		    + " and   asspersonrelright.asstypeid in ("
		    + "					     select typeid" 
		    + "					     from   assoriginalpostype" 
		    + "					     where  assoriginalpostype.originalid = " + Integer.toString(origid)
		    + "					     and    assoriginalpostype.deleted = false"
		    + "					     ) "
                    + " and ( (  asspersonrelright.lineid in ("
	       	    + "                             select lineid" 
		    + "				    from   assoriginalposline "
		    + "				    where  assoriginalposline.originalid = " + Integer.toString(origid)
		    + "				    and    assoriginalposline.deleted = false "
		    + "				    ) "
		    + "      )"
		    + " or  ( " + Integer.toString(origid) + " not in ("
		    + "                       select originalid "
		    + "			      from assoriginalposline "
		    + "			      where assoriginalposline.deleted = false)"
		    + "	     ));";
		*/
		try {
		    ResultSet rs = db.executeQuery(query);
		    if ( rs.next() )
		        hasRight = rs.getBoolean("juttunen");
                } catch (Exception e) { System.out.println(e.getMessage()); }	
		
	        try {
                    if(!wasConnected) db.disconnect();
                 } catch (Exception jotain) {}                         

		return hasRight;		 
	}

   
        /**
	 * Exceute query to find out if given user group has specified right
	 *
	 * @param rightid  The right we are interested in
	 * @param groupid  The user group we are interested in
	 */
              public boolean hasGroupRight(int rightid, int groupid) {
		 
	        boolean hasRight = false;
      		boolean wasConnected = false;
                try {
		  if(!db.isConnected()) db.connect();
	 	  else wasConnected = true;
		} catch (Exception muuta) {}
		
		String query = 
		      " select distinct true as juttunen "  
		    + " from  assusergrouprelright "
		    + " where assusergrouprelright.deleted = false"
		    + " and   assusergrouprelright.groupid = " + Integer.toString(groupid)
		    + " and   assusergrouprelright.rightid = " + Integer.toString(rightid)
		    + " ;";

		try {
		    ResultSet rs = db.executeQuery(query);
		    if ( rs.next() )
		        hasRight = rs.getBoolean("juttunen");
                } catch (Exception e) { System.out.println(e.getMessage()); }	
		
	        try {
                    if(!wasConnected) db.disconnect();
                 } catch (Exception jotain) {}                         

        	return hasRight;		 
	}

    

}
